Crate deepseek_recipe_encoding

Crate deepseek_recipe_encoding 

Model-specific conversation rendering and token encoding.

V4 and V4.1 provide prompt rendering. Attach a tokenizer to an encoding to encode conversations into token IDs.

Re-exports

pub use v4::dsv4;
pub use v4::dsv41;

Modules

v4

Structs

RenderedPrompt
A rendered prompt and the images its placeholders refer to.

Enums

EncodingError
Failure to encode a conversation.

Traits

PromptEncoding
Render model prompts and encode conversations into token IDs.
TokenizerEncoder
Encode text into model token ids.