pub struct RenderedPrompt {
pub prompt: String,
pub image_sources: Vec<ImageSource>,
}Expand description
A rendered prompt and the images its placeholders refer to.
Fields
prompt: StringModel input string.
image_sources: Vec<ImageSource>Image sources in the order their placeholders appear in the prompt.